Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrecht Van Lommel <brechtvanlommel@pandora.be>2010-03-23 18:04:06 +0300
committerBrecht Van Lommel <brechtvanlommel@pandora.be>2010-03-23 18:04:06 +0300
commit5bc2d5350776e1fd063a62a40255589083ea6217 (patch)
tree244554e6379dfefcc9e47960b15e0564671b7eb3 /source/blender/makesrna/RNA_types.h
parent33e0ea0e5940dba240dc68fe44b5295c31dcb974 (diff)
fix for parsing python args to rna functions, was using allocated size as argument count.
(commit 27670 by Campbell from render25 branch)
Diffstat (limited to 'source/blender/makesrna/RNA_types.h')
-rw-r--r--source/blender/makesrna/RNA_types.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/source/blender/makesrna/RNA_types.h b/source/blender/makesrna/RNA_types.h
index e09bd19774c..6eecd091b7f 100644
--- a/source/blender/makesrna/RNA_types.h
+++ b/source/blender/makesrna/RNA_types.h
@@ -245,8 +245,10 @@ typedef struct ParameterList {
/* storage for parameters */
void *data;
- /* store the parameter count */
- int tot;
+ /* store the parameter size */
+ int alloc_size;
+
+ int arg_count, ret_count;
/* function passed at creation time */
struct FunctionRNA *func;